@@ -4,17 +4,40 @@ package Sumu::Perl::Modules;
 
 =head1 NAME
 
-    Perl Modules
+    Sumu Perl Modules
 
 =head1 VERSION
 
-version 0.3.7
+version 0.4.0
 
-=head2 DESC
+=head2 SYNOPSIS
+
+    Usage:
+    
+        my $module = $c->param('module');
+            
+            chomp $module;
+        
+        my $modules = Sumu::Perl::Modules->new();
+
+        my ($mod, $dirs, $files) = $modules->_dirs(current_user => $current_user, module => "$module");
+
+        my ($mod, $out) = $modules->_doc( module => $module );
+
+
+=head2 DESCRIPTION
 
     List all installed Perl Modules on your system
-    
-=cut
+
+    Tested in:
+
+        Dist: 
+
+            Ubuntu 22.04 (WSL)
+
+        UI: 
+
+            Rocky Linux 9 (Hyper-V)
 
 =head2 Strictures
 
@@ -23,15 +46,18 @@ version 0.3.7
 =cut
 
 use strict;
-#use warnings;
+use warnings;
 
 =head2 our VERSION
 
-    our $VERSION = '0.3.7'
+    our $VERSION = '0.4.0'
+
+    This version number is updated automatically!
 
 =cut
 
-our $VERSION = '0.3.7';
+our $VERSION = '0.4.0';
+
 
 =head2 Internals
 
@@ -45,6 +71,7 @@ our @ISA = ("Exporter");
 
 our @EXPORT_OK = qw(
     NAME 
+    new
     _extutils 
     _dirs 
     _doc
@@ -76,6 +103,8 @@ sub new {
 
 =head3 Required Modules
 
+    Eporter
+    
     ExtUtils::Installed
 
 =cut
@@ -87,7 +116,7 @@ my $inst = ExtUtils::Installed->new();
 
 =head3 Sub _extutils
 
-    Returns List of modules 
+    Returns List of modules as a table
 
 =cut
 
